package	jp.co.sds_corp.streaming;

import java.net.URL;

import javax.swing.JOptionPane;

import jp.co.sds_corp.util.common.CmnProperty;
import jp.co.sds_corp.util.common.CmnString;
import jp.co.sds_corp.util.config.DOMConfiguration;
import jp.co.sds_corp.util.daemon.manager.DaemonManager;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;
import jp.co.sds_corp.util.pooh.dialog.DialogResource;
import jp.co.sds_corp.util.pooh.frame.FrameResource;
import jp.co.sds_corp.util.pooh.menu.SubMenuResource;
import jp.co.sds_corp.util.pooh.simple.SimpleButton;
import jp.co.sds_corp.util.pooh.simple.SimpleDialog;
import jp.co.sds_corp.util.pooh.simple.SimpleInternalFrame;
import jp.co.sds_corp.util.pooh.simple.SimpleMdiFrame;
import jp.co.sds_corp.util.pooh.top.TopWindow;

public class StreamingWindow extends SimpleMdiFrame implements TopWindow
{
	static final CmnLogger logger = CmnLogFactory.getLogger();
	DaemonManager	manager;

	public void initialFrame( String name ) throws Exception {
		CmnProperty prop = new CmnProperty( "StreamingPanel" );
		logger.debug(this, "property " + prop);
		URL url = new URL( prop.getString( "URL" ));
		logger.debug(this, "load daemon " + url);
		manager = DaemonManager.getInstance();
		manager.init( new DOMConfiguration( url ));
		manager.start();

		super.initialFrame( name );
		FrameResource frameRequest;
		SimpleInternalFrame frame;

/*
		frameRequest = getFrameResource( "CHART" );
		frame = super.createFrame( frameRequest );
		frame.setTitle( "USD/JPY" );
		ChartPanel chartPanel = (ChartPanel)frame.getChildPane();
		chartPanel.initPanel( "USD", "JPY", "SP", "2" );
		addFrame( frame );
*/

		frameRequest = getFrameResource( "FORWARD_GROUP" );
		frame = super.createFrame( frameRequest );
		frame.setTitle( "EUR/JPY" );
		ForwardPanel forwardPanel = (ForwardPanel)frame.getChildPane();
		forwardPanel.initPanel( "EUR", "JPY", "2" );
		addFrame( frame );

/**/
		String[] pairs = CmnString.getStringToken( prop.getString( "Pair" ), "," );
		String[] precs = CmnString.getStringToken( prop.getString( "Prec" ), "," );
		for ( int i = 0; i < pairs.length; i++ ) {
			String ccy1 = pairs[i].substring( 0, 3 );
			String ccy2 = pairs[i].substring( 3, 6 );
			String term = pairs[i].substring( 6, 8 );

			frameRequest = getFrameResource( "STREAMING_GROUP" );
			frame = super.createFrame( frameRequest );
			frame.setTitle( ccy1 + "/" + ccy2 + " " + term );
			StreamingPanel panel = (StreamingPanel)frame.getChildPane();
			panel.initPanel( ccy1, ccy2, term, precs[i] );
			addFrame( frame );
		}
/**/
	}

	public void mainLoop() {
		try {
			showframe( true );
		} catch ( Exception e ) {
			e.printStackTrace();
		}
	}

	/**
	* 「アプリケーション」－「Streaming」が選択された場合に
	*  呼び出されます。
	*  menu.xmlのlistenerアトリビュートに@doStreamingと指定されています。
	*/
	public void doStreaming( SubMenuResource res ) {
		try {
			DialogResource dialogRequest = getDialogResource( "DIALOG1" );
			SimpleDialog dialog = super.createDialog( dialogRequest );
			dialog.show();
			if( dialog.getAction() == SimpleButton.OK ) {
				String key  = (String )dialogRequest.getUserAttribute();
				String ccy1 = (String )toplevel.getUserAttribute( key, "CCY1");
				String ccy2 = (String )toplevel.getUserAttribute( key, "CCY2");
				String term = (String )toplevel.getUserAttribute( key, "TERM");
				String prec = (String )toplevel.getUserAttribute( key, "PREC");
				String type = (String )toplevel.getUserAttribute( key, "TYPE");

				SimpleInternalFrame frame = null;
				FrameResource frameRequest = null;
				if ( type.equals( "Outright" )) {
					frameRequest = getFrameResource( "STREAMING_GROUP" );
					frame = super.createFrame(frameRequest);
					StreamingPanel panel = (StreamingPanel)frame.getChildPane();
					frame.setTitle( ccy1 + "/" + ccy2 + " " + term );
					panel.initPanel(ccy1, ccy2, term, prec);
				} else if ( type.equals( "Chart" )) {
					frameRequest = getFrameResource( "CHART" );
					frame = super.createFrame(frameRequest);
					frame.setTitle( ccy1 + "/" + ccy2 );
					ChartPanel panel = (ChartPanel)frame.getChildPane();
					panel.initPanel(ccy1, ccy2, term, prec);
				} else if ( type.equals( "Forward" )) {
					frameRequest = getFrameResource( "FORWARD_GROUP" );
					frame = super.createFrame(frameRequest);
					frame.setTitle( ccy1 + "/" + ccy2 );
					ForwardPanel panel = (ForwardPanel)frame.getChildPane();
					panel.initPanel(ccy1, ccy2, prec);
				} else {
					return;
				}

				addFrame(frame);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	*
	*/
	public void doStreamingFrameChange(SubMenuResource res) {
		try {
			String	ccy1;
			String	ccy2;
			String	term;
			int		nPrec;
			FrameResource resource = getActiveFrameResource();
			StreamingPanel panel = (StreamingPanel)resource.getPanel();
			ccy1 = panel.getCcy1();
			ccy2 = panel.getCcy2();
			term = panel.getTerm();
			nPrec = panel.getPrec();

			DialogResource dialogRequest = getDialogResource("DIALOG1");
			SimpleDialog dialog = super.createDialog(dialogRequest);
			SetPair dpnl = (SetPair )dialog.getChildPane();
			dpnl.setValue( ccy1, ccy2, term );
			dialog.show();
			if( dialog.getAction()==SimpleButton.OK) {
				String key  = (String)dialogRequest.getUserAttribute();
				ccy1 = (String)toplevel.getUserAttribute(key, "CCY1");
				ccy2 = (String)toplevel.getUserAttribute(key, "CCY2");
				term = (String)toplevel.getUserAttribute(key, "TERM");
				String prec = (String)toplevel.getUserAttribute(key, "PREC");

				resource.getFrame().setTitle(ccy1 + "/" + ccy2 + " " + term);
				panel.closed();
				panel.initPanel(ccy1, ccy2, term, prec);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void doChartChange(SubMenuResource res) {
		try {
			String	ccy1;
			String	ccy2;
			String	term;
			int		nPrec;
			FrameResource resource = getActiveFrameResource();
			ChartPanel panel = (ChartPanel)resource.getPanel();
/*
			ccy1 = panel.getCcy1();
			ccy2 = panel.getCcy2();
			term = panel.getTerm();
			nPrec = panel.getPrec();
*/

			DialogResource dialogRequest = getDialogResource("DIALOG1");
			SimpleDialog dialog = super.createDialog(dialogRequest);
			dialog.show();
			if( dialog.getAction()==SimpleButton.OK) {
				String key  = (String)dialogRequest.getUserAttribute();
				ccy1 = (String)toplevel.getUserAttribute(key, "CCY1");
				ccy2 = (String)toplevel.getUserAttribute(key, "CCY2");
				term = (String)toplevel.getUserAttribute(key, "TERM");
				String prec = (String)toplevel.getUserAttribute(key, "PREC");

				resource.getFrame().setTitle(ccy1 + "/" + ccy2 + " " + term);
				panel.closed();
				panel.initPanel(ccy1, ccy2, term, prec);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void doForwardChange(SubMenuResource res) {
		try {
			String	ccy1;
			String	ccy2;
			String	term;
			int		nPrec;
			FrameResource resource = getActiveFrameResource();
			ForwardPanel panel = (ForwardPanel)resource.getPanel();
/*
			ccy1 = panel.getCcy1();
			ccy2 = panel.getCcy2();
			term = panel.getTerm();
			nPrec = panel.getPrec();
*/

			DialogResource dialogRequest = getDialogResource("DIALOG1");
			SimpleDialog dialog = super.createDialog(dialogRequest);
			if( dialog.getAction()==SimpleButton.OK) {
				String key  = (String)dialogRequest.getUserAttribute();
				ccy1 = (String)toplevel.getUserAttribute(key, "CCY1");
				ccy2 = (String)toplevel.getUserAttribute(key, "CCY2");
				term = (String)toplevel.getUserAttribute(key, "TERM");
				String prec = (String)toplevel.getUserAttribute(key, "PREC");

				resource.getFrame().setTitle(ccy1 + "/" + ccy2 + " " + term);
				panel.closed();
				panel.initPanel(ccy1, ccy2, prec);
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void createFrame() {
	}
	public void exit() {
		super.exit();
	}
	public boolean systemButtonClosing() {
		int option = JOptionPane.showConfirmDialog(this,
			"システムを終了しますか？", "確認", 0 );
		return option == 0;
	}

	public void defaultUIResource() {
	}
}
